qachi

package
v0.0.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 29, 2026 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Overview

Package qachi exists for symmetry with other framework adapters. Chi already uses net/http middleware signatures, so the core middleware can be used directly without importing this package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func QAMiddleware

func QAMiddleware(v qaauthmw.Verifier, opts ...qaauthmw.Option) func(http.Handler) http.Handler

Middleware returns a chi-compatible middleware (which is just net/http middleware).

func UserID

func UserID(ctx context.Context) (string, bool)

Types

This section is empty.

Jump to